@@ -14,6 +14,7 @@ from typing import Any, Tuple, Union, List, Dict, Type, TypeVar
 from lxml import html
 import requests
 from escriptorium_connector.dtos.line_dtos import PostMoveLine, PostMoveLines, PutBulkUpdateLines
+from escriptorium_connector.dtos.transcription_dtos import PostBulkCreateTranscriptions
 from requests.packages.urllib3.util import Retry
 import logging
 import json
@@ -80,6 +81,7 @@ from escriptorium_connector.dtos import (
     GetTranscription,
     GetTranscriptions,
     PostTranscription,
+    PutTranscription,
 )
 
 # endregion
@@ -137,6 +139,7 @@ class EscriptoriumConnector:
         api_url: str = None,
         project: str = None,
         verify_ssl: bool = True,
+        http_read_timeout: int = None
     ):
         """Simplified access to eScriptorium
 
@@ -210,7 +213,7 @@ class EscriptoriumConnector:
             ],
             backoff_factor=1,
         )
-        adapter = TimeoutHTTPAdapter(max_retries=retry_strategy)
+        adapter = TimeoutHTTPAdapter(max_retries=retry_strategy, timeout=http_read_timeout)
 
         def assert_status_hook(response, *args, **kwargs):
             try:
@@ -1160,6 +1163,35 @@ class EscriptoriumConnector:
             GetTranscriptions,
         )
 
+    def bulk_delete_transcriptions(
+        self, doc_pk: int, part_pk: int, transcription_ids: List[int]
+    ) -> None:
+        body = { 'lines': transcription_ids }
+        self.__post_url(
+            f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/transcriptions/bulk_delete/", body
+        )
+
+        # Return nothing. The http response hook will raise an exception if an error is returned
+
+    def bulk_create_transcriptions(
+        self, doc_pk: int, part_pk: int, transcriptions: List[PostTranscription]
+    ) -> PostBulkCreateTranscriptions:
+        body = {
+            'lines': transcriptions
+        }
+        return self.__post_url_serialized(
+            f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/transcriptions/bulk_create/", body, PostBulkCreateTranscriptions
+        )
+
+    def bulk_update_transcriptions(
+        self, doc_pk: int, part_pk: int, transcriptions: List[PutTranscription]
+    ) -> List[GetTranscription]:
+        body = {
+            'lines': transcriptions
+        }
+        return self.__put_url_serialized(
+            f"{self.api_url}documents/{doc_pk}/parts/{part_pk}/transcriptions/bulk_update/", body, List[GetTranscription]
+        )
     # endregion
 
     # region Annotation API
